Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(6668)

Unified Diff: chrome/browser/ui/views/download/download_item_view.h

Issue 10453101: Convert most of the rest of chrome to ImageSkia (Closed) Base URL: svn://svn.chromium.org/chrome/trunk/src
Patch Set: Created 8 years, 6 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: chrome/browser/ui/views/download/download_item_view.h
diff --git a/chrome/browser/ui/views/download/download_item_view.h b/chrome/browser/ui/views/download/download_item_view.h
index 387ab476f461eb8ceb92e5f1ac2aec162898afd5..342f5386ed6833626a47c02370055bb0f5170132 100644
--- a/chrome/browser/ui/views/download/download_item_view.h
+++ b/chrome/browser/ui/views/download/download_item_view.h
@@ -37,11 +37,11 @@
class BaseDownloadItemModel;
class DownloadShelfView;
-class SkBitmap;
class DownloadShelfContextMenuView;
namespace gfx {
class Image;
+class ImageSkia;
}
namespace ui {
@@ -120,22 +120,22 @@ class DownloadItemView : public views::ButtonListener,
// The image set associated with the part containing the icon and text.
struct BodyImageSet {
- SkBitmap* top_left;
- SkBitmap* left;
- SkBitmap* bottom_left;
- SkBitmap* top;
- SkBitmap* center;
- SkBitmap* bottom;
- SkBitmap* top_right;
- SkBitmap* right;
- SkBitmap* bottom_right;
+ gfx::ImageSkia* top_left;
+ gfx::ImageSkia* left;
+ gfx::ImageSkia* bottom_left;
+ gfx::ImageSkia* top;
+ gfx::ImageSkia* center;
+ gfx::ImageSkia* bottom;
+ gfx::ImageSkia* top_right;
+ gfx::ImageSkia* right;
+ gfx::ImageSkia* bottom_right;
};
// The image set associated with the drop-down button on the right.
struct DropDownImageSet {
- SkBitmap* top;
- SkBitmap* center;
- SkBitmap* bottom;
+ gfx::ImageSkia* top;
+ gfx::ImageSkia* center;
+ gfx::ImageSkia* bottom;
};
void OpenDownload();
@@ -143,12 +143,12 @@ class DownloadItemView : public views::ButtonListener,
void LoadIcon();
void LoadIconIfItemPathChanged();
// Convenience method to paint the 3 vertical bitmaps (bottom, middle, top)
// that form the background.
- void PaintBitmaps(gfx::Canvas* canvas,
- const SkBitmap* top_bitmap,
- const SkBitmap* center_bitmap,
- const SkBitmap* bottom_bitmap,
+ void PaintImages(gfx::Canvas* canvas,
+ const gfx::ImageSkia* top_image,
+ const gfx::ImageSkia* center_image,
+ const gfx::ImageSkia* bottom_image,
int x,
int y,
int height,
@@ -208,7 +208,7 @@ class DownloadItemView : public views::ButtonListener,
DropDownImageSet pushed_drop_down_image_set_;
// The warning icon showns for dangerous downloads.
- const SkBitmap* warning_icon_;
+ const gfx::ImageSkia* warning_icon_;
// The model we query for display information
content::DownloadItem* download_;
« no previous file with comments | « chrome/browser/ui/views/detachable_toolbar_view.cc ('k') | chrome/browser/ui/views/download/download_item_view.cc » ('j') | no next file with comments »
@@ -143,12 +143,12 @@ class DownloadItemView : public views::ButtonListener,
void LoadIcon();
void LoadIconIfItemPathChanged();
- // Convenience method to paint the 3 vertical bitmaps (bottom, middle, top)
+ // Convenience method to paint the 3 vertical images (bottom, middle, top)
// that form the background.

Powered by Google App Engine
This is Rietveld 408576698